@@ -105,8 +105,16 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
             context = m.group(2).replace("</br>","</br>\n")
             context = m.group(2).replace("<br/>","<br/>\n")
         else :
-            print("# cannot find content", file=sys.stderr, flush=True)
-            break
+            lines = [ln for ln in rsp.text.splitlines()]
+            started = False
+            for _, ln in enumerate(lines) :
+                if re.search(r"<\/*br\s*\/*>",ln) :
+                    started = True
+                    context += ln
+                if started and re.search(r"</div>",ln)  :
+                    break
+                if started :
+                    context += ln
         if len(context) < 200 :
             print("# context length abnormal. most likely hit with rate limiter", file=sys.stderr, flush=True)
             break
